@@ -249,11 +249,11 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk
-import aws_cdk.aws_secretsmanager
-import aws_cdk.aws_ssm
-import aws_cdk.custom_resources
-import constructs
+import aws_cdk as _aws_cdk_ceddda9d
+import aws_cdk.aws_secretsmanager as _aws_cdk_aws_secretsmanager_ceddda9d
+import aws_cdk.aws_ssm as _aws_cdk_aws_ssm_ceddda9d
+import aws_cdk.custom_resources as _aws_cdk_custom_resources_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 @jsii.data_type(
@@ -277,7 +277,7 @@ class GithubApiCall:
         ignore_error_codes_matching: typing.Optional[builtins.str] = None,
         output_paths: typing.Optional[typing.Sequence[builtins.str]] = None,
         parameters: typing.Any = None,
-        physical_resource_id: typing.Optional[aws_cdk.custom_resources.PhysicalResourceId] = None,
+        physical_resource_id: typing.Optional[_aws_cdk_custom_resources_ceddda9d.PhysicalResourceId] = None,
     ) -> None:
         '''
         :param endpoint: The endpoint to call.
@@ -288,24 +288,14 @@ class GithubApiCall:
         :param physical_resource_id: The physical resource id of the custom resource for this call. Default: undefined - for "Create" requests, defaults to the event's RequestId, for "Update" and "Delete", defaults to the current ``PhysicalResourceId``.
         '''
         if __debug__:
-            def stub(
-                *,
-                endpoint: builtins.str,
-                method: builtins.str,
-                ignore_error_codes_matching: typing.Optional[builtins.str] = None,
-                output_paths: typing.Optional[typing.Sequence[builtins.str]] = None,
-                parameters: typing.Any = None,
-                physical_resource_id: typing.Optional[aws_cdk.custom_resources.PhysicalResourceId] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__c44a6ed82823e6106770483149fb381def9b614340cbdf2ee1f568994d4994bd)
             check_type(argname="argument endpoint", value=endpoint, expected_type=type_hints["endpoint"])
             check_type(argname="argument method", value=method, expected_type=type_hints["method"])
             check_type(argname="argument ignore_error_codes_matching", value=ignore_error_codes_matching, expected_type=type_hints["ignore_error_codes_matching"])
             check_type(argname="argument output_paths", value=output_paths, expected_type=type_hints["output_paths"])
             check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
             check_type(argname="argument physical_resource_id", value=physical_resource_id, expected_type=type_hints["physical_resource_id"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "endpoint": endpoint,
             "method": method,
         }
@@ -376,7 +366,7 @@ class GithubApiCall:
     @builtins.property
     def physical_resource_id(
         self,
-    ) -> typing.Optional[aws_cdk.custom_resources.PhysicalResourceId]:
+    ) -> typing.Optional[_aws_cdk_custom_resources_ceddda9d.PhysicalResourceId]:
         '''The physical resource id of the custom resource for this call.
 
         :default: undefined - for "Create" requests, defaults to the event's RequestId, for "Update" and "Delete", defaults to the current ``PhysicalResourceId``.
@@ -384,7 +374,7 @@ class GithubApiCall:
         :see: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/crpg-ref-responses.html
         '''
         result = self._values.get("physical_resource_id")
-        return typing.cast(typing.Optional[aws_cdk.custom_resources.PhysicalResourceId], result)
+        return typing.cast(typing.Optional[_aws_cdk_custom_resources_ceddda9d.PhysicalResourceId], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -399,7 +389,7 @@ class GithubApiCall:
 
 
 class GithubCustomResource(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@pepperize/cdk-github.GithubCustomResource",
 ):
@@ -445,13 +435,13 @@ class GithubCustomResource(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         auth_options: "IAuthOptions",
-        on_create: typing.Optional[typing.Union[GithubApiCall, typing.Dict[str, typing.Any]]] = None,
-        on_delete: typing.Optional[typing.Union[GithubApiCall, typing.Dict[str, typing.Any]]] = None,
-        on_update: typing.Optional[typing.Union[GithubApiCall, typing.Dict[str, typing.Any]]] = None,
+        on_create: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
+        on_delete: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
+        on_update: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
         resource_type: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -464,18 +454,7 @@ class GithubCustomResource(
         :param resource_type: Cloudformation Resource type.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                auth_options: IAuthOptions,
-                on_create: typing.Optional[typing.Union[GithubApiCall, typing.Dict[str, typing.Any]]] = None,
-                on_delete: typing.Optional[typing.Union[GithubApiCall, typing.Dict[str, typing.Any]]] = None,
-                on_update: typing.Optional[typing.Union[GithubApiCall, typing.Dict[str, typing.Any]]] = None,
-                resource_type: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__34ac3907b3892d527d8ed5ffbe6f3d09b02d1b1041cd1e29f5f4f7710a70cefa)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GithubCustomResourceProps(
@@ -489,7 +468,7 @@ class GithubCustomResource(
         jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="getAtt")
-    def get_att(self, attribute_name: builtins.str) -> aws_cdk.Reference:
+    def get_att(self, attribute_name: builtins.str) -> _aws_cdk_ceddda9d.Reference:
         '''Returns the value of an attribute of the custom resource of an arbitrary type.
 
         Attributes are returned from the custom resource provider through the
@@ -503,11 +482,9 @@ class GithubCustomResource(
         use the convenience ``getAttString`` for string attributes.
         '''
         if __debug__:
-            def stub(attribute_name: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__d8325810a88873bf09eb989ddd0497b9ac3548fe3b018a03e606ef9ee2ba8669)
             check_type(argname="argument attribute_name", value=attribute_name, expected_type=type_hints["attribute_name"])
-        return typing.cast(aws_cdk.Reference, jsii.invoke(self, "getAtt", [attribute_name]))
+        return typing.cast(_aws_cdk_ceddda9d.Reference, jsii.invoke(self, "getAtt", [attribute_name]))
 
     @jsii.member(jsii_name="getAttString")
     def get_att_string(self, attribute_name: builtins.str) -> builtins.str:
@@ -521,9 +498,7 @@ class GithubCustomResource(
         :return: a token for ``Fn::GetAtt`` encoded as a string.
         '''
         if __debug__:
-            def stub(attribute_name: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__f3048bbbb682877779122b1b60e30674d866852cd1cd0d63fb0a6eadc3ce39cf)
             check_type(argname="argument attribute_name", value=attribute_name, expected_type=type_hints["attribute_name"])
         return typing.cast(builtins.str, jsii.invoke(self, "getAttString", [attribute_name]))
 
@@ -550,9 +525,9 @@ class GithubCustomResourceProps:
         self,
         *,
         auth_options: "IAuthOptions",
-        on_create: typing.Optional[typing.Union[GithubApiCall, typing.Dict[str, typing.Any]]] = None,
-        on_delete: typing.Optional[typing.Union[GithubApiCall, typing.Dict[str, typing.Any]]] = None,
-        on_update: typing.Optional[typing.Union[GithubApiCall, typing.Dict[str, typing.Any]]] = None,
+        on_create: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
+        on_delete: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
+        on_update: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
         resource_type: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -569,22 +544,13 @@ class GithubCustomResourceProps:
         if isinstance(on_update, dict):
             on_update = GithubApiCall(**on_update)
         if __debug__:
-            def stub(
-                *,
-                auth_options: IAuthOptions,
-                on_create: typing.Optional[typing.Union[GithubApiCall, typing.Dict[str, typing.Any]]] = None,
-                on_delete: typing.Optional[typing.Union[GithubApiCall, typing.Dict[str, typing.Any]]] = None,
-                on_update: typing.Optional[typing.Union[GithubApiCall, typing.Dict[str, typing.Any]]] = None,
-                resource_type: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__1c8edec08159118c71ac4a94db67b290e347e016adad191face6c2fea17c250d)
             check_type(argname="argument auth_options", value=auth_options, expected_type=type_hints["auth_options"])
             check_type(argname="argument on_create", value=on_create, expected_type=type_hints["on_create"])
             check_type(argname="argument on_delete", value=on_delete, expected_type=type_hints["on_delete"])
             check_type(argname="argument on_update", value=on_update, expected_type=type_hints["on_update"])
             check_type(argname="argument resource_type", value=resource_type, expected_type=type_hints["resource_type"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "auth_options": auth_options,
         }
         if on_create is not None:
@@ -670,7 +636,10 @@ class AuthOptions(
 
     @jsii.member(jsii_name="appAuth")
     @builtins.classmethod
-    def app_auth(cls, secret: aws_cdk.aws_secretsmanager.ISecret) -> "AuthOptions":
+    def app_auth(
+        cls,
+        secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
+    ) -> "AuthOptions":
         '''GitHub App or installation authentication.
 
         :param secret: -
@@ -678,15 +647,16 @@ class AuthOptions(
         :see: https://github.com/octokit/auth-app.js/#readme
         '''
         if __debug__:
-            def stub(secret: aws_cdk.aws_secretsmanager.ISecret) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__40bd18010eabb96176b1524b3cbf1fdd6e0dab0f27d89bc17eebf1e4b01a64e0)
             check_type(argname="argument secret", value=secret, expected_type=type_hints["secret"])
         return typing.cast("AuthOptions", jsii.sinvoke(cls, "appAuth", [secret]))
 
     @jsii.member(jsii_name="tokenAuth")
     @builtins.classmethod
-    def token_auth(cls, parameter: aws_cdk.aws_ssm.IParameter) -> "AuthOptions":
+    def token_auth(
+        cls,
+        parameter: _aws_cdk_aws_ssm_ceddda9d.IParameter,
+    ) -> "AuthOptions":
         '''Personal Access Token authentication.
 
         :param parameter: -
@@ -694,9 +664,7 @@ class AuthOptions(
         :see: https://github.com/octokit/auth-token.js#readme
         '''
         if __debug__:
-            def stub(parameter: aws_cdk.aws_ssm.IParameter) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__9ba10bce7d2f7f9a64938fe085321969cb9b61af281c396716449878413f1d99)
             check_type(argname="argument parameter", value=parameter, expected_type=type_hints["parameter"])
         return typing.cast("AuthOptions", jsii.sinvoke(cls, "tokenAuth", [parameter]))
 
@@ -726,3 +694,63 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__c44a6ed82823e6106770483149fb381def9b614340cbdf2ee1f568994d4994bd(
+    *,
+    endpoint: builtins.str,
+    method: builtins.str,
+    ignore_error_codes_matching: typing.Optional[builtins.str] = None,
+    output_paths: typing.Optional[typing.Sequence[builtins.str]] = None,
+    parameters: typing.Any = None,
+    physical_resource_id: typing.Optional[_aws_cdk_custom_resources_ceddda9d.PhysicalResourceId] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__34ac3907b3892d527d8ed5ffbe6f3d09b02d1b1041cd1e29f5f4f7710a70cefa(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    auth_options: IAuthOptions,
+    on_create: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
+    on_delete: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
+    on_update: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
+    resource_type: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d8325810a88873bf09eb989ddd0497b9ac3548fe3b018a03e606ef9ee2ba8669(
+    attribute_name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f3048bbbb682877779122b1b60e30674d866852cd1cd0d63fb0a6eadc3ce39cf(
+    attribute_name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1c8edec08159118c71ac4a94db67b290e347e016adad191face6c2fea17c250d(
+    *,
+    auth_options: IAuthOptions,
+    on_create: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
+    on_delete: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
+    on_update: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
+    resource_type: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__40bd18010eabb96176b1524b3cbf1fdd6e0dab0f27d89bc17eebf1e4b01a64e0(
+    secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9ba10bce7d2f7f9a64938fe085321969cb9b61af281c396716449878413f1d99(
+    parameter: _aws_cdk_aws_ssm_ceddda9d.IParameter,
+) -> None:
+    """Type checking stubs"""
+    pass
